rule win_hawkball_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.hawkball."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.hawkball"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 83780c00 7506 33c0 8be5 }
            // n = 4, score = 200
            //   83780c00             | cmp                 dword ptr [eax + 0xc], 0
            //   7506                 | jne                 8
            //   33c0                 | xor                 eax, eax
            //   8be5                 | mov                 esp, ebp

        $sequence_1 = { 53 e8???????? 037dfc 83c40c 81ffffff0300 }
            // n = 5, score = 200
            //   53                   | push                ebx
            //   e8????????           |                     
            //   037dfc               | add                 edi, dword ptr [ebp - 4]
            //   83c40c               | add                 esp, 0xc
            //   81ffffff0300         | cmp                 edi, 0x3ffff

        $sequence_2 = { 0f84c6000000 6a04 8d442418 c744241860ea0000 50 6a06 57 }
            // n = 7, score = 200
            //   0f84c6000000         | je                  0xcc
            //   6a04                 | push                4
            //   8d442418             | lea                 eax, [esp + 0x18]
            //   c744241860ea0000     | mov                 dword ptr [esp + 0x18], 0xea60
            //   50                   | push                eax
            //   6a06                 | push                6
            //   57                   | push                edi

        $sequence_3 = { 53 ff15???????? ff742414 8b35???????? ffd6 53 }
            // n = 6, score = 200
            //   53                   | push                ebx
            //   ff15????????         |                     
            //   ff742414             | push                dword ptr [esp + 0x14]
            //   8b35????????         |                     
            //   ffd6                 | call                esi
            //   53                   | push                ebx

        $sequence_4 = { 85c9 746d 837dfc28 7d13 6b55fc05 69c2e8030000 }
            // n = 6, score = 200
            //   85c9                 | test                ecx, ecx
            //   746d                 | je                  0x6f
            //   837dfc28             | cmp                 dword ptr [ebp - 4], 0x28
            //   7d13                 | jge                 0x15
            //   6b55fc05             | imul                edx, dword ptr [ebp - 4], 5
            //   69c2e8030000         | imul                eax, edx, 0x3e8

        $sequence_5 = { 50 ff15???????? 897001 c600ff c7400500000000 }
            // n = 5, score = 200
            //   50                   | push                eax
            //   ff15????????         |                     
            //   897001               | mov                 dword ptr [eax + 1], esi
            //   c600ff               | mov                 byte ptr [eax], 0xff
            //   c7400500000000       | mov                 dword ptr [eax + 5], 0

        $sequence_6 = { b9???????? e8???????? a3???????? 833d????????00 740b 8b0d???????? }
            // n = 6, score = 200
            //   b9????????           |                     
            //   e8????????           |                     
            //   a3????????           |                     
            //   833d????????00       |                     
            //   740b                 | je                  0xd
            //   8b0d????????         |                     

        $sequence_7 = { 837dfc28 7d13 6b55fc05 69c2e8030000 50 }
            // n = 5, score = 200
            //   837dfc28             | cmp                 dword ptr [ebp - 4], 0x28
            //   7d13                 | jge                 0x15
            //   6b55fc05             | imul                edx, dword ptr [ebp - 4], 5
            //   69c2e8030000         | imul                eax, edx, 0x3e8
            //   50                   | push                eax

        $sequence_8 = { 7405 8d4a10 eb47 b911000000 }
            // n = 4, score = 200
            //   7405                 | je                  7
            //   8d4a10               | lea                 ecx, [edx + 0x10]
            //   eb47                 | jmp                 0x49
            //   b911000000           | mov                 ecx, 0x11

        $sequence_9 = { 8be5 5d c3 6a59 ff15???????? 85c0 }
            // n = 6, score = 200
            //   8be5                 | mov                 esp, ebp
            //   5d                   | pop                 ebp
            //   c3                   | ret                 
            //   6a59                 | push                0x59
            //   ff15????????         |                     
            //   85c0                 | test                eax, eax

    condition:
        7 of them and filesize < 229376
}